@@ -5,8 +5,9 @@ import {
   GERMAN_GERMANY,
   CHINESE_SIMPLIFIED,
   BRAZILIAN_PORTUGUESE,
-} from '@grafana/data/unstable';
-import { LocaleFileLoader, PSEUDO_LOCALE } from 'app/core/internationalization/constants';
+  PSEUDO_LOCALE,
+} from '@grafana/i18n';
+import { LocaleFileLoader } from 'app/core/internationalization/constants';
 
 export const ENTERPRISE_I18N_NAMESPACE = 'grafana-enterprise';
 
